package javax.swing.text;

import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.Graphics;
import javax.swing.Icon;

public class IconView extends View
{
    private Icon c;
    
    public IconView(Element element) {
        super(element);
        this.c = StyleConstants.getIcon(element.getAttributes());
    }
    
    @Override
    public void paint(Graphics graphics, Shape shape) {
        Rectangle bounds = shape.getBounds();
        this.c.paintIcon(this.getContainer(), graphics, bounds.x, bounds.y);
    }
    
    @Override
    public float getPreferredSpan(int i) {
        switch (i) {
            case 0: {
                return (float)this.c.getIconWidth();
            }
            case 1: {
                return (float)this.c.getIconHeight();
            }
            default: {
                throw new IllegalArgumentException("Invalid axis: " + i);
            }
        }
    }
    
    @Override
    public float getAlignment(int n) {
        switch (n) {
            case 1: {
                return 1.0f;
            }
            default: {
                return super.getAlignment(n);
            }
        }
    }
    
    @Override
    public Shape modelToView(int i, Shape shape, Position.Bias bias) throws BadLocationException {
        int startOffset = this.getStartOffset();
        int endOffset = this.getEndOffset();
        if (i >= startOffset && i <= endOffset) {
            Rectangle bounds = shape.getBounds();
            if (i == endOffset) {
                bounds.x += bounds.width;
            }
            bounds.width = 0;
            return bounds;
        }
        else {
            throw new BadLocationException(i + " not in range " + startOffset + "," + endOffset, i);
        }
    }
    
    @Override
    public int viewToModel(float n, float n2, Shape shape, Position.Bias[] array) {
        Rectangle rectangle = (Rectangle)shape;
        if (n < (float)(rectangle.x + rectangle.width / 2)) {
            array[0] = Position.Bias.Forward;
            return this.getStartOffset();
        }
        array[0] = Position.Bias.Backward;
        return this.getEndOffset();
    }
}
